---
name: 'Bug report'
about: 'Report a bug to help improve fastMRI'
labels: 'bug'
---

Please:

- [ ] Check for duplicate issues.
- [ ] Provide a simple example for how to reproduce the bug.
- [ ] If applicable, include full error messages/tracebacks.
